@@ -27,12 +27,16 @@
 #include <locale.h>
 
 #include <QDebug>
-#include <QtTest>
+#include <QTest>
+#include <QThread>
+#include <QStandardPaths>
+#include <QProcess>
 
 #include <libintl.h>
 
 #include <klocalizedstring.h>
 
+#include <QRegularExpression>
 #include <QSet>
 #include <QString>
 
@@ -211,11 +215,33 @@ void KLocalizedStringTest::correctSubs()
              QString("E < *mc^2*"));
     QCOMPARE(xi18nc("@info", "E &lt; <emphasis>mc^2</emphasis>"),
              QString("<html>E &lt; <i>mc^2</i></html>"));
+    QCOMPARE(xi18nc("@info:status", "E &lt; <emphasis>mc^2</emphasis>"),
+             QString("E < *mc^2*"));
+    QCOMPARE(xi18nc("@info:progress", "E &lt; <emphasis>mc^2</emphasis>"),
+             QString("E < *mc^2*"));
+    QCOMPARE(xi18nc("@info:tooltip", "E &lt; <emphasis>mc^2</emphasis>"),
+             QString("<html>E &lt; <i>mc^2</i></html>"));
+    QCOMPARE(xi18nc("@info:shell", "E &lt; <emphasis>mc^2</emphasis>"),
+             QString("E < *mc^2*"));
     QCOMPARE(xi18n("E = mc^&#x0032;"),
              QString("E = mc^2"));
     QCOMPARE(xi18n("E = mc^&#0050;"),
              QString("E = mc^2"));
 
+    // with additional whitespace
+    QCOMPARE(xi18nc(" @info:progress ", "E &lt; <emphasis>mc^2</emphasis>"),
+             QString("E < *mc^2*"));
+    QCOMPARE(xi18nc(" @info:tooltip ", "E &lt; <emphasis>mc^2</emphasis>"),
+             QString("<html>E &lt; <i>mc^2</i></html>"));
+    QCOMPARE(xi18nc(" @info: progress ", "E &lt; <emphasis>mc^2</emphasis>"), // not parsed as a cue
+             QString("<html>E &lt; <i>mc^2</i></html>"));
+    QCOMPARE(xi18nc(" @info: tooltip ", "E &lt; <emphasis>mc^2</emphasis>"), // not parsed as a cue
+             QString("<html>E &lt; <i>mc^2</i></html>"));
+
+    QTest::ignoreMessage(QtWarningMsg, "\"Unknown subcue ':doesnotexist' in UI marker in context {@info:doesnotexist}.\"");
+    QCOMPARE(xi18nc("@info:doesnotexist", "E &lt; <emphasis>mc^2</emphasis>"),
+             QString("<html>E &lt; <i>mc^2</i></html>"));
+
     // Number formatting.
     QCOMPARE(ki18n("%1").subs(42).toString(),
              QString("42"));
@@ -584,6 +610,14 @@ void KLocalizedStringTest::untranslatedText()
     QCOMPARE(s.untranslatedText(), "Job");
 }
 
+void KLocalizedStringTest::brokenTags()
+{
+    QTest::ignoreMessage(QtWarningMsg, QRegularExpression("Markup error in message {.*}: Opening and ending tag mismatch.. Last tag parsed: email. Complete message follows"));
+    QCOMPARE(xi18nc("@info",
+                    "Send bug reports to <email>%1<email>.", "konqi@kde.org"), // notice the missing '/' before "email"
+             QString("<html>Send bug reports to <email>konqi@kde.org<email>.</html>"));
+}
+
 
 #include <QThreadPool>
 #include <QtConcurrentRun>
